@@ -30,7 +30,7 @@ from .runners import (
     DefaultRunners,
 )
 from .site import (
-    Synchronize,
+    Synchronize, GotoCurrentSiteQueue,
     WorkingSites, ExchangeSites,
     MinioFileUploader, MinioFileDownloader,
     RequestRevisionsAs,
@@ -192,6 +192,7 @@ class Synchronization(flow.Object):
     
     _project = flow.Parent()
     synchronize_files = flow.Child(SynchronizeFiles)
+    show_jobs = flow.Child(GotoCurrentSiteQueue)
     request_revisions_as = flow.Child(RequestRevisionsAs)
 
     def summary(self):
