@@ -9,6 +9,8 @@ from kabaret import flow
 from kabaret.subprocess_manager.runner_factory import Runner, logger
 from kabaret.subprocess_manager.flow import RunAction
 
+from ..utils.kabaret.subprocess_manager.runner_factory import Runner
+
 
 CHOICES = ["blend", "kra", "png", "jpg", "txt", "abc", "mov", "psd", "aep", "zip", "mp4", "fbx", "ai", "json", "jsx"]
 CHOICES_ICONS = {
@@ -34,63 +36,8 @@ CHOICES_ICONS = {
 # Runners
 # -----------------
 
-class BaseRunner(Runner):
 
-    def run(self):
-        cmd = [self.executable()]
-        cmd.extend(self.argv())
-
-        env = self.env()
-
-        os_flags = {}
-
-        # Disowning processes in linux/mac
-        if hasattr(os, "setsid"):
-            os_flags["preexec_fn"] = os.setsid
-
-        # Disowning processes in windows
-        if hasattr(subprocess, "STARTUPINFO"):
-            # Detach the process
-            os_flags["creationflags"] = subprocess.CREATE_NEW_CONSOLE
-
-            # Hide the process console
-            startupinfo = subprocess.STARTUPINFO()
-            if self.show_terminal():
-                flag = "/C"
-                if self.keep_terminal():
-                    flag = "/K"
-                cmd = ["cmd", flag] + cmd
-            else:
-                startupinfo.dwFlags |= subprocess.STARTF_USESHOWWINDOW
-
-            os_flags["startupinfo"] = startupinfo
-
-        logger.info("Running Subprocess: %r", cmd)
-        
-        if not os.path.exists(self.get_log_path()):
-            os.mkdir(self.get_log_path())
-
-        tznow = datetime.now().astimezone().strftime("%Y-%m-%dT%H-%M-%S%z")
-        log_out_path = "%s/%s_%s.log" % (
-            self.get_log_path(),
-            self.runner_name(),
-            tznow,
-        )
-        log_err_path = "%s/%s_%s_error.log" % (
-            self.get_log_path(),
-            self.runner_name(),
-            tznow,
-        )
-
-        with open(log_out_path, "w+") as out, open(log_err_path, "w+") as err:
-            popen = subprocess.Popen(cmd, env=env, stdout=out, stderr=err, **os_flags)
-            self._popen = popen
-
-    def get_log_path(self):
-        return "%s/.libreflow/log" % Path.home()
-
-
-class DefaultEditor(BaseRunner):
+class DefaultEditor(Runner):
     @classmethod
     def can_edit(cls, filename):
         return True
@@ -109,7 +56,7 @@ class DefaultEditor(BaseRunner):
             super(DefaultEditor, self).run()
 
 
-class EditFileRunner(BaseRunner):
+class EditFileRunner(Runner):
 
     ICON = ("icons.flow", "action")
 
@@ -221,7 +168,7 @@ class Firefox(EditFileRunner):
         return True
 
 
-class PythonRunner(BaseRunner):
+class PythonRunner(Runner):
 
     def executable(self):
         return sys.executable
